This file contains a complete list of all the features available in
Astrolog version 2.25, and documentation on how to use each option.
The file is divided into four parts:

1) A summary list of all the main features which are accessed via
command line parameter switches, along with a list of single keypress
commands that can be given in an X window (assuming you have X
windows) to change the display in various ways.

2) The list of command switches and keypresses is repeated, but after
each option is listed a more lengthy description of the details of
this feature.

3) Additional things such as some important compile time options, the
default parameter file, and descriptions of the things that appear in
the Astrolog text displays, are described.

4) Finally, there is a description of the different X window chart
displays and how they are organized, and the X windows features in
general. (Looking for a quick impressive display to prove that this
was worth compiling? In unix try: astrolog -Xn -XG -Xw 400. :)


************************
LIST OF COMMAND SWITCHES
************************

Astrolog command switches (version 2.25) (June 1992):
 -H: Display this help message.
 -O: Display available planets and other celestial objects.
 -O0: Line -O but ignore any restrictions.
 -R [<obj1> [<obj2> ..]: Restrict specific bodies from displays.
 -R0 [<obj1> ..]: Like -R but restrict everything first.
 -R[C,u,U]: Restrict all minor cusps, all uranians, or stars.
 -C: Include non-angular house cusps in charts.
 -u: Include transneptunian/uranian bodies in charts.
 -U: Include locations of fixed background stars in charts.
 -U[z,l,n,b]: Order by azimuth, altitude, name, or brightness.
 -A [<0-18>]: Display available aspects or limit their number.
 -Ao <orb1> [<orb2> ..]: Specify max orbs for each aspect.
 -AO [..]: Like -Ao but suspend objects' max orb restrictions.

Switches which affect how a chart is computed:
 -c <value>: Select a different default system of houses.
     (0 = Placidus, 1 = Koch, 2 = Equal, 3 = Campanus, 4 = Meridian,
     5 = Regiomontanus, 6 = Porphry, 7 = Morinus, 8 = Topocentric, 9 = None.)
 -s: Compute siderial instead of the normal tropical chart.
 -s0: Display locations as right ascension instead of degrees.
 -h [<objnum>]: Compute positions centered on specified object.
 -p <month> <day> <year>: Cast progressed chart based for date.
 -pn: Cast progressed chart based on current date now.
 -p0 <days>: Set no. of days to progress / day (default 365.25).
 -x <1-360>: Cast harmonic chart based on specified factor.
 -1 [<objnum>]: Cast chart with specified object on ascendant.
 -3: Display objects in their zodiac decan positions.
 -f: Display houses as sign positions (flip them).
 -G: Display houses based on geographic location only.
 -+ <days>: Cast chart for specified no. of days in the future.
 -- <days>: Cast chart for specified no. of days in the past.

Switches which determine in what format the chart is displayed:
 -v: Display list of object positions (chosen by default).
 -v0: Like -v but express velocities relative to average speed.
 -w: Display chart on screen in a graphic house wheel format.
 -w0: Like -w but show objects in houses 4..9 in reverse order.
 -g: Display aspect and midpoint grid among planets.
 -g0: Like -g but flag aspect configurations (e.g. Yod's) too.
 -g0: For comparison charts, show midpoints instead of aspects.
 -ga: Like -g but indicate applying instead of difference orbs.
 -Z: Display planet locations with respect to the local horizon.
 -S: Display x,y,z coordinate positions of planets.
 -I: Display interpretation of planetary influences.
 -L [<step>]: Display astro-graph locations of planetary angles.
 -L0 [..]: Like -L but display list of latitude crossings too.
 -d: Print all aspects and changes occurring in a day.
 -d0: Like -d but print all aspects for the entire month.
 -dp <month> <year>: Print aspects within progressed chart.
 -e: Print all options for chart (i.e. -v-w-g0-Z-S-I-L0-d).

Switches which affect how the chart parameters are obtained:
 -n: Compute chart for this exact moment using current time.
 -a <month> <date> <year> <time> <zone> <long> <lat>:
     Compute chart automatically given specified data.
 -z: Assume Daylight time (change default zone appropriately).
 -z <zone>: Change the default time zone (for -d-q-T-E options).
 -l <long> <lat>: Change the default longitude & latitude.
 -q <month> <date> <year>: Compute chart for noon on date.
 -q0 <month> <date> <year> <time>: Like -q but include time too.
 -i <file>: Compute chart based on info in file.
 -o <file> [..]: Write parameters of current chart to file.
 -o0 <file> [..]: Like -o but output planet/house positions.

Other features or major modes:
 -r <file1> <file2>: Compute a relationship synastry chart.
 -rc <file1> <file2>: Compute a composite chart.
 -rm <file1> <file2>: Compute a time space midpoint chart.
 -r0 <file1> <file2>: Keep the charts separate in comparison.
 -t <file>: Compute current house transits for particular chart.
 -T <file> <month> <year>: Compute all transits in month for chart.
 -T0 <..>: Like -T but include transits of the Moon as well.
 -Tp <file> <month> <year>: Compute all progressions in month for chart.
 -E <month> <year>: Display ephemeris for given month.
 -E0 <..>: Like -E but include Chiron and the asteroids as well.

Switches to access X window options:
 -X: Create a graphics chart instead of displaying it as text.
 -Xb: Create X bitmap instead of putting graphics in window.
 -XB: Display X chart on root instead of in a separate window.
 -Xm: For color monitors, display charts in black and white.
 -Xr: Create window or bitmap in reversed colors (B on W).
 -Xw <hor> [<ver>]: Change the size of the chart window.
 -Xs <percentage>: Change the size of characters by n%.
 -Xi: Display chart in slightly modified form.
 -XT: Inhibit display of chart info at bottom of window.
 -XW: Simply create the bitmap of the world.
 -XP: Create the bitmap of the world, but as a polar projection.
 -XG [<degrees>]: Display the bitmap of the world as a globe.
 -Xn: Start up chart or globe display in animation mode.
 -Xo <file>: Write output bitmap to specified file.
Also, press 'H' within X window for list of key press options.


Astrolog window keypress options (version 2.25):
 Press 'H' to display this list of key options.
 Press 'p' to toggle pause status on or off.
 Press 'x' to toggle fg/bg colors in window.
 Press 'm' to toggle color/monochrome display in window.
 Press 'T' to toggle header info on current chart in window.
 Press 'i' to toggle status of the minor chart modification.
 Press 'l' to toggle labeling of object points in chart.
 Press 'v' to display current chart in window on text screen.
 Press 'R' to toggle restriction status of minor objects.
 Press 'C' to toggle restriction status of minor house cusps.
 Press 'u' to toggle restriction status of uranian planets.
 Press 'U' to toggle restriction status of fixed stars.
 Press 's', 'h', 'f', 'F' to toggle status of siderial zodiac,
        heliocentric charts, domal charts, and decan charts.
 Press 'O' and 'o' to recall/store a previous chart from memory.
 Press 'Q' to resize wheel chart display to a square.
 Press 'B' to dump current window contents to root background.
 Press '<' and '>' to decrease/increase the scale size of the
       glyphs and the size of world map.
 Press '[' and ']' to decrease/increase tilt in globe display.
 Press 'N' to toggle animation status on or off. Charts will
       be updated to current status and globe will rotate.
 Press '!'-'(' to begin updating current chart by adding times.
       !: seconds, @: minutes, #: hours, $: days, : months,
       ^: years, &: years*10, *: years*100, (: years*1000.
 Press 'r' to reverse direction of time-lapse or animation.
 Press '1'-'9' to set rate of animation to 'n' degrees, etc.
 Press 'V','L','A','Z','S','W','G','P' to switch to normal (-v),
       astrograph (-L), grid (-g), local (-Z), space (-S),
       world (-XW), globe (-XG), and polar (-XP) modes.
 Press 'q' to terminate the window and program.

 Left   mouse button: Draw lines on chart in window.
 Middle mouse button: Print coordinates of pointer on world map.
 Right  mouse button: Terminate the window and program.


**********************************
DESCRIPTION OF EACH COMMAND SWITCH
**********************************

Note: When specifying command switches, the leading dashes are
optional, and aren't necessary. For example, the command "astrolog -i
chartfile -R -u -U -Z -Xs 300 -Xi -XB" can be abbreviated as "astrolog
i chartfile R u U Z Xs 300 Xi XB". (This is subject to a couple of
minor limitations, in that one can't have the -1 or -3 option follow a
-R restriction list of numbers, for obvious reasons.)

----

Astrolog command switches (version 2.25) (June 1992):

-H: Display this help message.

  This option displays a list exactly like the one given above on the
  screen.

-O: Display available planets and other celestial objects.

  Similar to the -A option below, the -O option will list all the
  planets and other celestial objects used by the program, and their
  numbers as recognized by the -R restrictions mentioned below. This
  list will also show the zodiac signs that planets rule, fall in, are
  exalted in, and debilitated in. (Remember that when -O is encountered,
  it immediately executes and terminates the program, so any modifying
  switches must be before it.)

-O0: Line -O but ignore any restrictions.

  The -O switch above simply displays a list of all the objects, cusps,
  uranians, and stars, along with their index numbers. This list can be
  affected by the -R restrictions, and the -C, -u, and -U switches must
  be included in order for all of Astrolog's objects to get listed. In
  order to make it easier to simply display a list of all 78 objects
  Astrolog recognizes, the new -O0 option is just like -O (and is
  equivalent to "-C -u -U -O") except that it will ignore all
  restrictions and always list every object. Stars are printed in the
  list along with their azimuth, altitude, and brightness values.

-R [<obj1> [<obj2> ..]: Restrict specific bodies from displays.

  The ability to restrict the transit (-T) and daily aspect (-d) scans
  to just certain bodies has been implemented with the -R switch. Using
  -R by itself will prevent the asteroids, Chiron, the Part of Fortune
  and the Vertex from being in any of the lists. One may also give a
  list of one or more numbers representing planets to be ignored (e.g. 1
  = Sun, 2 = Moon, 3 = Mercury, etc) so that a complete custom setup can
  be obtained (e.g. -R 1 2 3 4 5 will cause all of the inner planets to
  be ignored). More than one -R switch can be combined (e.g. -R -R 16
  will cause the asteroids, etc, and the North Node to be ignored; the
  first -R gets rid of the asteroids, etc, and the second one deletes
  the North Node.) Also, specifying the same particular body more than
  once will cause it to be included again, or in other words, -R
  <objectnum> complements the status of whether it is to be ignored or
  not (e.g. -R -R 15 will cause all of the asteroids, etc, excluding
  Vesta, to be ignored; the first -R makes causes the asteroids to be
  ignored, and specifying Vesta in the second -R makes it reappear.)

-R0 [<obj1> ..]: Like -R but restrict everything first.

  The -R0 option will cause ALL of the bodies to be ignored, which is
  useful if you are looking for just the transits/aspects of a few
  planets (e.g. -R0 6 7 will cause everything but Juptier and Saturn to
  be ignored.) Combining all these methods can cause whatever you are
  looking for in transits and aspects to be quickly found without having
  to wade through lots of stuff you aren't interested in.

-R[C,u,U]: Restrict all minor cusps, all uranians, or stars.

  These three switches are similar to the -R0 option in that they
  initially restrict objects, i.e. all the minor cusps, Uranians, and
  stars, (described below) respectively from appearing. For example, if
  you want to include only the star Sirius in an X window chart without
  having to also include all the other stars (or having to enter a very
  long restriction list), do: "astrolog -U -RU 48 -X", which will
  include the stars, and then restrict them all except Sirius, before
  making the chart.

-C: Include non-angular house cusps in charts.

  This option must be indicated to include the four minor house cusps
  (i.e. 11th, 12th, 2nd, 3rd) in the various chart options, such as the
  -g aspect grids, -T transit searches, the X wheel chart, etc. This
  option of course won't have any effect on certain charts where only
  physical bodies are shown (e.g. -Z, -S, -L) or where all house cusps
  are already indicated in the chart (e.g. -v, -w).

-u: Include transneptunian/uranian bodies in charts.

  Display the locations of the "Uranian" planets with the -u switch.
  Transneptunian or Uranian planets are an interesting subset of
  astrology which includes various objects alleged to be beyond Pluto.
  (Do: astrolog -u -O to list the eight Uranian bodies.) Anyway,
  Astrolog will display the zodiac positions of these planets as well if
  one includes this option, and will print their positions after the
  main planets, or include them in the other chart types. (Note: the
  Uranians don't have any formal glyphs that I'm aware of, so therefore
  they are displayed in the X charts as three letter abbreviations of
  their name.)

-U: Include locations of fixed background stars in charts.

  Astrolog has the ability to display the positions of 46 of the
  brightest and most important stars in the sky. To include these stars
  in a chart, use the -U "universe" option. The 43 brightest stars, i.e.
  all those with apparent magnitude values < 2.0 are included, in
  addition to three dimmer stars which are considered significant, i.e.:
  Polaris the North star, the Pleiades star cluster (home of our
  extraterrestrial cousins), and Zeta Reticuli (home of the Grey
  aliens.) One bright star is called "Orion", which is formally Alnilam,
  the middle star of Orion's belt. Since stars are fixed in the sky,
  they will never change position in the -s siderial zodiac, although
  they will slowly precess forward in the normal tropical zodiac. The -R
  restriction option can be used to determine which stars are actually
  included, although the -U option needs to be included to get any stars
  at all. In X windows, the stars are denoted by three letter
  abbreviations (as are the uranians and minor house cusps), and are
  colored according to their brightness: yellow for stars brighter than
  (less than) magnitude 0.0, gold for dimmer ones from 0.0 to 1.0,
  orange for those from 1.0 to 2.0, and finally the dimmest special
  stars with a magnitude greater than 2.0 are red.

-U[z,l,n,b]: Order by azimuth, altitude, name, or brightness.

  In the -v standard chart, -Z horizon chart, and in the -O object list,
  where all the stars are printed sequentially, it can sometimes be
  confusing to locate the star you want among 42 others. The -U option
  can be modified to sort the stars in various ways. If one uses -Ub
  instead of just -U, the stars will be listed in order from brightest
  to dimmest. Doing -Un instead of -U will alphabetize the stars by
  name. -Ul will sort them by their altitude from highest in the sky to
  lowest, while -Uz will sort them by their zodiac position. Note that
  any star ordering will have no visible effect in X windows, and one
  must still use the default ordering when passing numbers to the -R
  option to restrict various stars.

-A [<0-18>]: Display available aspects or limit their number.

  The '-A' command switch gives a list of all 18 supported aspects,
  their abbreviations as used in the aspect grids, their angles, and
  their orbs. It will list the number of each aspect in addition to all
  the other info already there (e.g. conjunct = 1, opposition = 2, etc.)
  so one can easily figure out what exact number to pass to the -A
  option when changing the number of aspects used (see below). Finally,
  it will display a brief verbal description of what each aspect glyph
  look like. This is in case one doesn't know what aspects the weird
  symbols in the -g -X window displays are referring to.

  For those who don't like all these aspects, specifying -A <number>
  will limit the number of aspects (e.g. -A 5 will make charts with only
  the five major aspects listed in them).

-Ao <orb1> [<orb2> ..]: Specify max orbs for each aspect.

  Change the default orbs of the various aspects with the -Ao <orb1>
  <orb2>... <orbn> switch. Do you not like the 7 degree orbs for
  conjunctions that are in there by default? One can change the first n
  aspect orbs (i.e. as many orb values that one puts after the -Ao)
  anywhere from just the conjunction to all 18 aspects. Non-integer
  values are allowed of course. Use negative orb values to completely
  eliminate an aspect from ever appearing. For example: astrolog -A 6
  -Ao 5 5 -1 10 narrows the orbs for Conjunction and Opposition,
  completely eliminates the Square, widens the orb for Trines, and
  leaves the Sextiles and Inconjuncts in the default values. Note that
  for very wide orbs more than one aspect may apply for a particular
  angle, in which case the more fundamental aspect is chosen. Also for
  wide aspects the decimal value of the orb may be lost in the -g text
  grid (due to too many characters) and their might be some slight
  overlap in the X window -g cells.

-AO [..]: Like -Ao but suspend objects' max orb restrictions.

  Note that Astrolog imposes restrictions on the max orb that any
  particular aspect can have to certain particular objects, namely the
  node, fortune, and vertex, which can't and shouldn't have aspects to
  them in excess of 2 degrees. One can suspend these restrictions by
  replacing the -Ao <orbs> option above, invoking it as -AO <orbs>
  instead. For a fun (and perhaps useful) display, try: astrolog -A 1
  -AO 180 -g [-X], and see everything conjunct everything else.


Switches which affect how a chart is computed:

-c <value>: Select a different default system of houses.
(0 = Placidus, 1 = Koch, 2 = Equal, 3 = Campanus, 4 = Meridian,
5 = Regiomontanus, 6 = Porphry, 7 = Morinus, 8 = Topocentric, 9 = None.)

  Ten different house systems are supported: Invoke as astrolog -c
  <number> to change the system from the default of Placidus. (System 9
  refers to no houses at all, or in other words where the Ascendant will
  always be 0 degrees Aries, the Nadir 0 degrees Cancer, etc, which is
  useful for the extended chart animations as described later where
  having houses at all can tend to get in the way, and one can even
  observe the precession of the equinoxes with this system if used in
  conjunction with the -s siderial chart option.)

-s: Compute siderial instead of the normal tropical chart.

  With this option, the chart will be just like the normal charts as
  most commonly used in astrology, except that all the zodiac positions
  will be shifted (to be about 24 degrees earlier). This is because the
  option casts siderial charts which are based on the positions of the
  fixed stars (i.e. Aries starts at the constellation Aries) rather than
  the seasons (i.e. Aries starts at the Spring or Vernal Equinox.) Due
  to the "precession of the equinoxes" the the position of the Sun at
  the Equinoxes has been gradually happening at an earlier point in the
  siderial zodiac each year (taking about 2100 years change signs.)

-s0: Display locations as right ascension instead of degrees.

  For astronomers out there, this -s0 option will print all planetary
  positions in the right ascension hours/minutes format instead of the
  sign/degrees/minutes astrologers are accustomed to. This will affect
  how the objects are listed in the -v display, and how the star
  azimuths are displayed in the -O list. For example, 0 degrees Aries is
  represented as 0 hr, 0 min; 0 Cancer goes to 6 hr, 0 min, and so on
  through the 24 hour clock.

-h [<objnum>]: Compute positions centered on specified object.

  Normal astrology charts are based on the positions of the planets
  relative to the Earth. However, this option allows seeing of the
  zodiac positions with respect to the Sun's (or any other planet's)
  point of view. The -h option when invoked by itself will display a
  heliocentric chart: the Sun in the original listing will be replaced
  with the Earth's position as seen from the Sun in the heliocentric
  chart, with the other planets' positions modified accordingly. For
  bodies other than the Sun, the option takes a parameter to indicate
  which planet to center the chart on, e.g. do -h 5 to cast a Mars
  centered chart. (Moon centered charts aren't allowed; in fact, note
  that the -h option won't ever affect the Moon, which will always be
  displayed as seen from the Earth, no matter what the center body is
  set to, since it's not a formal planet.

-p <month> <day> <year>: Cast progressed chart based for date.

  A secondary progression chart for a particular date can be cast using the
  '-p <month> <date> <year>' command switch. (Note, I'm not sure if the house
  cusps are progressed correctly, but they're reasonably close to what is
  properly expected.)

-pn: Cast progressed chart based on current date now.

  The -pn switch is like the -p <month> <date> <year> switch except that
  (like the -n switch) it assumes the current moment now to cast the
  progressed chart to. This is just another shorthand convenience to see
  what ones progressed chart is like presently; just do: astrolog -i
  file -pn.

-p0 <days>: Set no. of days to progress / day (default 365.25).

  User definable progression rates can be specified with this option.
  When using the -p progression option, Astrolog assumes you want the
  standard "year for a day" rate of secondary progressions. By passing
  different values to the -p0 switch, one can change the default "365.25
  days for a day" to any value they want for some less often used method
  of progression. For example, one can do "-p0 7 -pn" to do a week for a
  day, "-p0 -365.25 -pn" to get negative year for day progressions, and
  so on. (Note that "-p0 1" would be the same as if no progression were
  done at all.)

-x <1-360>: Cast harmonic chart based on specified factor.

  Harmonic charts (i.e. where all the planet positions are multiplied by a
  factor and the chart recast) are supported via the '-x' option. (e.g.
  -x 3 will make all trines conjunct in the chart displayed.)

-1 [<objnum>]: Cast chart with specified object on ascendant.

  The -1 <obj> option can be used to change the houses to force a
  particular object to be on the ascendant. This is useful in casting
  Solar charts or for when the time of birth is not exactly known. For
  example -1 2 will case a normal chart, but the house cusps will be
  rotated so that the moon is on the ascendant.

-3: Display objects in their zodiac decan positions.

  Decan displays are supported in Astrolog, and one can display a decan
  influenced chart with the -3 switch. The decan theory is that each
  sign in the zodiac can be divided into three parts: The first 10
  degrees (i.e. the first decan) is mainly influenced by the sign in
  question, the second 10 degrees (second decan) although still
  influenced by the sign in question is also somewhat influenced by the
  next sign of the same element, while the last decan is influenced by
  the third sign of the same element. The -3 switch applied to a chart
  will move each object into the sign of its decan. For example, if the
  Sun is at 29 degrees Aquarius and the Moon at 5 degrees Virgo, in the
  resulting chart, the Sun will go to Libra (26 degrees) and the Moon
  will remain in Virgo (although be at 15 degrees now since it was
  previously in the middle of the first decan of Virgo.)

-f: Display houses as sign positions (flip them).

  The -f option can be used to "flip" the signs and houses, i.e. display
  the house as a sign position and vice versa. For example having the
  Sun at 26 degrees Scorpio, 2/3 way though the 10th house, will cause
  the resulting Sun under the -f option to be at 20 degrees Capricorn,
  26/30th the way through the 8th house. This can be used to determine
  how far a planet is through a particular house, as well as for Domal
  chart analysis that Mark Kenski has informed me about. Domal analysis
  is based on the fact that for synastry comparisons, for example, a
  planet in Gemini and one in the 3rd house can be considered related in
  a way similar to a conjunction.

-G: Display houses based on geographic location only.

  This switch generates a special type of locational analysis chart,
  called a geodetic chart, in which the house cusps are computed from a
  different source, i.e. as a function of only the longitude and
  latitude. This basically gives every spot on the planet a different
  unique set of house cusps, and can be used to analyze the
  characteristics of different areas, and their influence on you if you
  insert your own planets in the houses. This type of chart was
  described in the January 1992 issue of Dell Horoscope magazine, from
  which I learned how to generate these charts. Basically, the Midheaven
  is approximately the longitude value converted from degrees into the
  appropriate zodiac sign; for example 0 degrees E goes to 0 degrees
  Aries, 30 degrees E goes to 0 degrees Taurus, etc.

-+ <days>: Cast chart for specified no. of days in the future.

  The -+ <#ofdays> option will cast a normal chart, but one for #ofdays in
  the future (or past if a negative value is given). One use for this is in
  combination with the -n and -d options. For instance, I often invoke the
  program as "astrolog -n -d" to see the exact times of today's aspects.
  However, just before midnight I might want to see what's going to happen
  in the following day, so I would do "astrolog -n -d -+ 1" to see the exact
  times for tomorrow's aspects.

-- <days>: Cast chart for specified no. of days in the past.

  This new "dash minus" option is just like the "dash plus" (-+) option
  described above, except it subtracts instead of adds the specified
  number of days from any chart cast. This is only for convenience, in
  that "-- 1" is the same as "-+ -1".

----

Switches which determine in what format the chart is displayed:

-v: Display list of object positions (chosen by default).

  This is just a formal specification for the standard chart listing of
  the planetary positions. One will get this chart by default if they
  don't specify any other chart types, and they will get it along with
  everything else in the -e option. Although it isn't necessary, it must
  be included if one wants this type of chart to be displayed along with
  some of the other chart types described below.

-v0: Like -v but express velocities relative to average speed.

  This switch is just like -v except that it modifies the planet
  velocities slightly. (See later for a description of these velocity
  fields.) Normally, it isn't a trivial task to determine precisely when
  a planet is going to change direction. This is because, for example,
  although a velocity of 0.010 degrees/day for fast moving Mercury means
  it's about to turn retrograde, the same velocity value is normal for
  slow moving Pluto. The -v0 switch divides the normal velocity values
  by how fast each planet moves with respect to the Sun, meaning that
  all planets will now have an average *relative* velocity value of
  1.000, and in all cases, a velocity of 2.000 means the planet is
  moving twice as fast as normal, and one of 0.010 means the planet is
  about to turn retrograde.

-w: Display chart on screen in a graphic house wheel format.

  Display of the chart in a nice wheel format is supported using the
  '-w' switch. (Special error case: If one of the houses gets too 'full'
  of planets, the planet will be put at the beginning of the next
  house.) The same chart header information as is at the top of the
  standard -v chart is printed in the middle of the wheel.

-w0: Like -w but show objects in houses 4..9 in reverse order.

  In the -w text wheel option, the objects in each house are printed
  from top to bottom in order from earliest in the house to latest. This
  looks good except for in houses 5..8 where this would appear backwards
  (e.g. a planet having just entered the 6th house from the 5th would be
  displayed right under the Descendant.) Therefore the objects from
  houses 4 through 9 are reversed and printed in order from bottom to
  top, making a more flowing looking wheel chart. If however, one always
  wants each house to be filled from its top to bottom regardless of
  which house, replace the -w with the -w0 switch

-g: Display midpoint & aspect grid instead of positions.

  Aspects and midpoint display are supported: Invoke as astrolog -g and
  a 20x20 grid showing the midpoint locations for each planet, and
  showing if any aspects are present and how accurate they are, is
  displayed. The planets are labeled down the diagonal of the grid, with
  the aspects to the lower left and the midpoints in the upper right.
  This is of course often used along with the -A* switches.

  Note that there is a way in the aspect grids to determine whether an
  aspect is slightly short of exact or slight long of exact. If the
  difference is displayed as "3.5" it means the aspect is 3.5 degrees
  long of exact; if it's displayed as "3,5", the aspect is 3.5 degrees
  short. (i.e. with a comma instead of a period; Yeah, I know that's a
  hack, but it's useful in determining whether the exact aspect just
  happened or is about to happen. (Note that conjuncts are always '.',
  and oppositions always ','.)

  Wider orbs are allowed for the Sun and Moon in the aspect grids.
  Normally, only the aspect in question determines the allowed orb, but
  the Sun and Moon will each add 1 degree to whatever the orb would have
  been. (This excludes minor objects such as the North Node, Part of
  Fortune, Vertex, and all the stars, for which the orbs are not allowed
  to ever exceed two degrees.)

-g0: Like -g but flag aspect configurations (e.g. Yod's) too.

  Search through the aspect grid for major aspect configurations,
  including Grand Trines, T-Squares, Grand Crosses, Yod's, Cradles, and
  Stelliums, with the -g0 option. (In a Stellium, three objects must all
  be conjunct with each other.) This option will produce the same aspect
  grid that -g displays, but afterwards will go through the grid and
  list any of these aspect configurations and what objects are forming
  them. (Of course, to see any Yod's, one has to -A 6 or more so that
  Inconjuncts will be included in the aspect grid.)

-g0: For comparison charts, show midpoints instead of aspects.

  For relationship aspect grids, the -g0 option will display a midpoint
  grid instead of an aspect grid between the planets in the two charts
  e.g. "-r0 chart1 chart2 -g0". (See later for descriptions of the
  relationship charts.)

-ga: Like -g but indicate applying instead of difference orbs.

  Ability to determine whether an aspect is applying or separating (is
  about to happen or just happened) is included in the -g option.
  Normally the aspect orbs are flagged as being '+' or '-' ('.' or ','
  in the text displays) based on whether they are greater or less than
  the exact amount (e.g. a 91 degree Square has a +1 degree orb while a
  89 degree one a -1 orb.) If one, however, invokes the -g option as -ga
  instead, a negative orb will indicate an applying aspect while a
  positive orb a separating one. (To estimate applying vs. separating,
  the program examines the planetary positions and their relative
  velocities at the time in question.)

-Z: Display planet locations with respect to the local horizon.

  The text display switch -Z prints out where each object is on the
  local horizon in terms of altitude and azimuth. For each object, the
  following is displayed: Its altitude on the local horizon from +90
  degrees (straight up) to -90 degrees (straight down), and its azimuth
  from 0..360 degrees, where 0 = due east, 90 = north, 180 = west, 270 =
  south. To make visualizing the azimuth easier, an "azimuth vector"
  with a N/S component and a W/E component is displayed, e.g. (1.00s
  0.33w) means that the object is mainly south, with its true angle
  being formed by an vector component west that's 1/3 the strength of
  the south component, i.e. the object is about 18 degrees west of
  south. This along with the altitude should make it easy to physically
  point to where any planet is at any moment, making it easy to locate
  planets in the night sky. This feature can also be used to determine
  the times that a planet rises and sets. Also displayed are altitude
  and azimuth differences between each object and the Sun and Moon,
  first showing the number of degrees that the Sun/Moon is "ahead" (or
  farther east in the zodiac) of the object in question, and then the
  number of degrees that the Sun/Moon is above the object in question.
  This feature can be used to roughly predict eclipses! Both the Sun and
  Moon span about 0.5 degrees in the sky, therefore if both the azimuth
  and altitude differences are < 0.5 (or 1.0 if the difference is
  between the Sun and Moon themselves) then the object in question is
  probably being occulted somewhat by the Sun/Moon. Note that there are
  three types of planetary position displays: Right ascension and
  declination showing the object's position with respect to the stars,
  longitude and latitude showing where on the Earth the object is
  straight up (as in the astro-graph zenith locations), and finally
  azimuth and altitude showing the positions of the object relative to
  the local horizon.

-S: Display x,y,z coordinate positions of planets.

  Solar system space based charts are available with the -S switch,
  which give the astronomical positions of each planet in terms of x, y,
  and z coordinates. Although not directly useful astrologically, it
  does give one a good view of how the planets actually were positioned
  at the time in question. For example, normal astrology doesn't make
  the distinction between the four different "forms" of say, a Mercury
  Venus Conjunction, i.e. they can either be Conjunct on the near side
  of the Sun, Conjunct on the far side of the Sun, or one can be on one
  side and the other on the other side. When the chart is actually
  displayed, for each body the following information is printed: The
  relative angle of the planet with respect to the central body, i.e.
  its zodiac position converted to the appropriate number from 0..360.
  This is followed by the x, y, and z coordinate positions of the
  object, in astronomical units from the central body. The x-axis
  increases in the direction of 0 degrees Aries (tropical zodiac), the
  y-axis increases in the direction of 0 degrees Cancer, and the z-axis
  is with respect to the Earth's orbit (meaning that the Sun and Earth
  always have a z-axis value of 0.0). Finally the overall length from
  the central body in AU is printed, which is just the diagonal as
  indicated by the x, y, z vectors. (The Earth and Sun are of course
  always about 1.0 AU from each other.) The Moon circles the Earth and
  isn't a part of the solar system proper; therefore, it is never in
  these charts. The -e everything option will include this chart in its
  listing of all the chart displays.

-I: Display interpretation of planetary influences.

  Another chart type is available - interpretation of influences. This
  is the beginning of a general interpretation ability for the program,
  although all it does now is calculate the relative "power" of each
  planet's placement, giving a general idea of the prominent areas of a
  chart. When such a chart is printed, each planet is given a point
  value, larger numbers indicating more strength. Each planet's strength
  is divided between two fields: the positioning in and of itself, and
  the power of the aspects it makes with the other planets. In addition
  to each field, the total of these two areas is printed, as well as the
  relative percentage of the planet in question with respect to all the
  planets combined. Each planet gets a ranking for its positioning,
  aspects, and total power as well, with the strongest getting #1, the
  next strongest #2, etc. The -e option will include this chart along
  with all the others as well in it's listing of all the chart displays.

  To determine the strength of the positioning of a planet, various
  things are taken into account: 1) The power of a planet in and of
  itself, e.g. the Sun and Moon are more powerful then the other
  planets. 2) The house placement of a planet, e.g. a planet in the 1st
  house is more powerful than one in the 2nd. 3) Whether a planet is in
  the sign it rules or is exalted in, e.g. Jupiter in Sag results in
  more power to Jupiter. 4) Whether a planet is in the house
  corresponding to the sign it rules or is exalted in, e.g. Jupiter in
  the 9th house. 5) Planets get more power if the signs they rule are
  occupied, e.g. a bunch of stuff in Aquarius gives more power to
  Uranus. 6) Planets get more power if the houses they rule are
  occupied, e.g. a bunch of stuff in the 11th house gives power to
  Uranus. 7) Finally, planets get power according to what houses the
  cusps of which fall in the signs they rule, i.e. the ruler of the
  Ascendant (and to less extent the Midheaven, and so on) gets lots of
  influence. Determining the strength of a planet's aspects is much
  easier, and is basically composed of the sum of the strength of each
  aspect the planet makes. Taken into account are: 1) The inherent
  influence of the planet being aspected to, e.g. Sun conjunct Jupiter
  gives more influence to Jupiter than Mercury conjunct Jupiter would.
  2) The influence of the aspect itself, e.g. Oppositions are more
  powerful then Sextiles. 3) Finally the orb of the aspect, i.e. exact
  aspects are more powerful than wide ones. (The influence of the orb
  varies linearly from max power at exact to zero power at the limit of
  the orb - sorry Maggie M. and Mark K. - no complex aspect wave
  functions, at least for this version :)

  Special thanks goes to Mark K. who initially presented this idea of
  interpreting overall influences to me. I basically just took his
  ideas, polished them a bit, and put it into the code. Interestingly,
  while programming this feature, I had a dream about him, in which he
  elaborated upon some of the ideas and even gave me suggestions for
  some of the planets' default power values (astral visitation?) And,
  while on the subject, I've had a couple of other Astrolog dreams; I
  had one neat one while working on the -h extension (described earlier)
  about a far distant future version of Astrolog that could actually
  teleport one to the places which they cast charts for :)

-L [<step>]: Display astro-graph locations of planetary angles.

  The '-L' option will take the standard chart information and generate
  the astro-graph positions of the planets. In other words, this does
  the exact same thing that Jim Lewis' Astro*Carto*Graphy maps do. It
  will display the longitude of where on the Earth at the time in
  question each object was on the midheaven and on the nadir, and the
  latitude of where the planets actually appeared at zenith. Also, for
  latitude increments of 5 degrees, the longitude of where the objects
  appeared on the ascendant and descendant is displayed. For text
  screens, one can pass an optional parameter to this -L (or -L0) option
  to change the default latitude step rate at which the Ascendant and
  Descendant lines are computed. Again, this value is by default 5
  degrees, although one can may increase or decrease it to any integer
  (subject to the restriction that the number 160 is divisible by it.)

-L0: Like -L but display list of latitude crossings too.

  Determination of latitude crossing points is included in the
  astro-graph routines! The -L0 option will do the same thing as the -L
  option, except that after displaying the longitude and latitude
  locations of the Asc/Desc/MC/IC lines, it will then search among the
  lines and display (in order from farthest North to farthest South) the
  latitude of any points where lines cross each other. This includes the
  curvey Asc/Desc lines crossing the straight MC/IC lines as well as
  cases where different Asc/Desc lines cross themselves. And unlike Jim
  Lewis' astro*carto*graphy, Astrolog will also display the longitude of
  the crossing (useful for Asc/Desc crossings) in addition to the
  latitude (as well allowing more planetary bodies to be included in the
  scan, and going farther North and South than Jim Lewis' printouts go.)
  Note however, that there is presently a small (very rare) minor
  omission glitch in the code, where if a crossing is within a couple of
  degrees of 180 deg W/E, it may not be displayed.

-d: Print all aspects and changes occurring in a day.

  The '-d' option will take the standard chart information, and for the
  day in question, display the exact times of all aspects that occur.
  This is just like the aspects-per-day as displayed in Jim Maynard's
  Celestial Guide books. (Displayed in local time as defined by the
  default zone, with accuracy to within a couple minutes.) This will
  tell any time two planets make aspects with each other, a planet
  changes its sign, or a planet goes retrograde or direct. Both the -d
  (and -T listed later) options will display the signs that any planets
  aspecting each other are in, in addition to the aspect itself (e.g.
  instead of just "Jupiter Tri Uranus", we have "Jupiter (Vir) Tri (Cap)
  Uranus". If a particular object is going retrograde, then its sign
  will be displayed in brackets instead of parentheses, and if a
  particular object is about to or has just gone retrograde or direct,
  then its sign will be in <>'s.

-d0: Like -d but print all aspects for the entire month.

  The -d option can now search the entire month for aspects between
  planets if one so desires. Specifying it as -d0 instead of just -d
  will go through the entire month instead of just the current day.
  (Combining this one with -R allows searching for important aspects,
  sign changes, etc.)

-dp <month> <year>: Print aspects within progressed chart.

  Another progression feature allows determining aspect times of
  progressed planets among themselves. The -i <file> -dp <month> <year>
  switch will, like the -d option, display times of aspects and sign
  changes, except that they will be for the chart in file, progressed
  throughout the month specified. Progressed planets move very slowly
  ("year for a day") so therefore there will usually be, if any, only a
  couple of aspects in a given month; again, one might want to
  substitute '0' for the month to scan the whole year. Also, since they
  move so slow, the accuracy is cut down, do the dates given are
  probably only accurate to the nearest day, in spite of the times given
  to the minute. Note that Astrolog can scan for aspects of: transiting
  planets among themselves (-d switch), transiting planets to natal
  planets (-T switch), progressed planets to natal planets (-Tp), and
  progressed planets among themselves (-dp). Only thing Astrolog can't
  do is do progressed planets to transiting planets, although that may
  change in the next version :)

-e: Print all options for chart (i.e. normal & -w0-g0-Z-L0-d). There

  are five main different formats of chart display available: The
  standard listing of planet positions, which you get without any
  switches; the aspect/midpoint grid you get with '-g', the house wheel
  you get with '-w', and so on. The -e "everything" option will display
  the chart in all five of these formats for about 650 lines of text!

----

Switches which affect how the chart parameters are obtained:

-n: Compute chart for this exact moment using current time.

  For those with unix systems who can handle the time calls (If your
  system pukes on trying to compile that, simply comment out the #define
  TIME line at the beginning), the program supports displaying the chart
  for the time at the current moment! In other words, invoke as astrolog
  -n and see where the planets are right now. (This is fun - the house
  cusps change 1' about every 4 seconds!) You will need to change the
  #defines for the default longitude and latitude in astrolog.h, or else
  specify where you are explicitly by using the -l switch to change the
  default location. (To figure out the time zone, the program uses the
  default value as in the DEFAULT_ZONE constant set at compile time.)

-a <month> <date> <year> <time> <zone> <long> <lat>:
Compute chart automatically given specified data.

  Normally one generates a chart by entering the seven data coordinates
  manually. A fast typist familiar with the program might prefer to give
  all the data at once, which can be done with this option. Simply list
  the seven parameters above, in the exact format as they would be given
  to the program were the user being prompted for them.

-z <zone>: Change the default time zone (for -d-q-T-E options).

  The -z <value> option can be used to change the default time zone to
  the value in question. For example, you can force the -E ephemeris and
  -T transits to be displayed at midnight GMT time instead of the local
  time with -z 0; or, for the East coast where by default the time zone
  is "5", you can do -z 4 during DST to properly display transits,
  aspects in day, and other lists in the local DST zone.

-z: Assume Daylight time (change default zone appropriately).

  Normally the -z option takes an argument which will then become the
  default time zone. If one, however, invokes it by itself, it will
  subtract one hour from whatever the default time zone presently is.
  This is useful since it is equivalent to adjusting any times printed
  to Daylight time, i.e. it will add one hour to any times displayed.
  (When entering the birth time for charts, one is supposed to subtract
  one hour if Daylight time was in effect; note that subtracting one
  hour from the time zone will do the same thing.) For example, over
  here on the West Coast, I have my default time zone compiled to be
  "8"; now that Daylight time is in effect here, I can do -z 7 or just
  -z to decrease the default time zone when I make a -T transit list,
  which will in effect add one hour to the local times displayed, or in
  effect "Spring ahead" the clock for me. (For a better way of adjusting
  Astrolog for Daylight time without having to specify -z all the time,
  recompile the program, or add one hour to the times in your head, use
  the "defaults" file described later to edit the time zone.) Remember
  that the -z (and -l) switches must be before any other switches they
  modify (such as -n) in order for the new default to take effect.

-l <long> <lat>: Change the default longitude & latitude.

  Like the -z option, the -l option can be used to change the default
  compile time global coordinates used in certain options, such as the
  -n cast chart for right now switch.

-q <month> <date> <year>: Compute chart for noon on date.

  The -q <month> <day> <year> option can be used to cast a quick chart
  for 12 noon on a particular date, using the default longitude and
  latitude. The DEFAULT_ZONE compile time constant is used for the time
  zone. Again, one example where this is useful is with the -d option,
  e.g. to see the times of exact aspects on a particular date, like your
  next birthday, your finals, etc.

-q0 <month> <date> <year> <time>: Like -q but include time too.

  The -q0 <month> <date> <year> <time> option takes the four parameters
  and casts a chart for the time in question. The time zone and location
  are taken from the default compiled values. This is just yet another
  useful shorthand way to quickly make a chart. Note that this is just
  like the -q <month> <date> <year> option except that -q always casts
  it for noon in the default zone. Also note that the -a option which
  takes all seven chart parameters can be duplicated with -q0 along with
  the -z <zone> and -l <long> <lat> options.

-i <file>: Compute chart based on info in file.

  See the -o option below.

-o <file> [..]: Write parameters of current chart to file.

  The program supports directing chart information to, and reading
  output from, data files. The '-o' option will dump all the birth data
  (the date and stuff, not the planet positions) to the specified file.
  The '-i' option will cast the chart based on the info in the file.
  (This allows you to put your birth data into a specific file, and cast
  your chart whenever you want to after that without having to reenter
  your birth data all the time.)

  Another file output feature, the ability to concatenate "comment
  lines" at the end of a data file, been been added to both the -o and
  -o0 options. (Some people have complained that the info in the
  Astrolog chart files are too cryptic.) After scanning the filename,
  the -o[0] option will then write any parameter that follows it at the
  end of the file, until a parameter beginning with a '-' (the next
  switch) is reached. For example: -o 'file' "Walter D. Pullen" Seattle
  will add my name and my birth city in two separate lines at the end of
  'file'. (In unix, quotes can be used to allow spaces within one
  parameter.)

-o0 <file> [..]: Like -o but output planet/house positions.

  Ability to write the actual sign and house positions of a chart to
  a file (instead of just the time and place) has been implemented via
  the -o0 <file> option. This option can be used interchangeably with
  the old -o output to file switch. The information written includes the
  zodiac position of the 20 main objects, their retrograde status and
  declination, as well as the positions of the (first six) house cusps.
  This file information can easily be passed into another program, and
  can be read back into Astrolog with the -i option. The -i option will
  automatically determine which type the file is, and will either use
  the given positions, or else calculate them as needed (note that some
  switches, such as the -c house system selection, will have no effect
  for this new file type.) Check an example of one of these files to see
  the precise format (a zodiac position is recorded as three numbers:
  degree in sign, sign as 1..12, and floating point minute within
  degree.) When the files are read back in, they will be flagged as
  "having no space or time" like the composite charts in the chart
  header displays.

  This file format can allow one to do things such as transits to
  composite charts (send the composite chart to file with -o0 option and
  then use that file as the first parameter to the -T option) composites
  between two composite charts (use -rc between two composite charts
  sent to a file) and even, if one is willing to do a small amount of
  editing, to do transits to midpoints or the 0 degrees Aries point.
  Note that one can easily edit the positions in the -o0 position file
  to be whatever they like, so one could replace some unimportant object
  (like the vertex) with 0 degrees Aries or an important midpoint value.
  Note that trying to still use the -o time and space output with an
  output chart that doesn't have space/time will confuse the program; it
  will either say it can't make the file or else will output the
  time/space of the most recent parameter file it read in.

----

Other features or major modes:

-r <file1> <file2>: Compute a relationship chart.

  Computing the relationship between two charts is supported. Invoke the
  program as 'astrolog -r <file_of_person1> <file_of_person2>' and the
  program will give you the relationship between the two charts. In
  other words, the program will use the positions of person2's planets
  and person1's houses. Use this with the -w option to get a wheel chart
  and you can do synastry. Note that transits can be computed with this
  by comparing your chart with the positions of the planets at the
  current moment (as in -n switch). To make this easier, you may specify
  the filename "now" for any file and the computer will use the current
  planet positions instead of looking for a like named file. (e.g.
  'astrolog -r me now' will compute transits for file 'me'.)

-rc <file1> <file2>: Compute a composite chart.

  The '-r' option can be used to generate composite relationship charts.
  Simply invoke it as '-rc <person1> <person2>' instead of just -r and a
  composite chart (i.e. composed of the midpoints of the planets, etc.
  of the two charts in question) will be generated.

-rm <file1> <file2>: Compute a time space midpoint chart.

  Time-space midpoint relationship charts are supported: Doing "-rm
  chart1 chart2" will calculate the time and location exactly half way
  between the times and locations as indicated in the two files. Unlike
  all other types of relationship charts, this one actually exists in
  space and time, and therefore can be treated like a single chart and
  can be output to a file with the -o option.

-r0 <file1> <file2>: Keep the charts separate in comparison.

  There is of course a distinction between synastry relationship charts
  and the actual comparison between two separate charts. The -r0 option
  is used to generate actual comparison charts. For example, combining
  -r0 with the -g switch will cause a full grid chart of the aspects
  between all the planets of the two charts (with person1's planets on
  the vertical axis and person2's on the horizontal) to be displayed.
  (Unfortunately, if all 20 of the default objects are left unrestricted
  here, the grid will exceed 80 columns.) The -r0 option can also be
  used with the -X switch to generate true relationship wheel charts,
  (described later). The -r0 option will act like the -r synastry option
  in certain displays that can't compare two charts; for example, '-r0
  -v' will act the same as just '-r -v'. (Note: the "-t file" current
  transit option is basically a shorthand way of doing "-r0 file now".)

-t <file>: Compute current house transits for particular chart.

  The command switch '-t <file>' can be used as a shortcut way to
  compute the current transits for the chart in <file>. (Saves you from
  having to mention the 'now' in the '-r0' option.)

-T <file> <month> <year>: Compute all transits in month for chart.

  The '-T <file> <month> <year>' option will scan the entire month
  specified, and print out any transits that happen, in that month, to
  the planets as listed in the specified <file>. There will be quite a
  few, even though fast moving objects like the moon aren't looked at,
  so you might want to use this with the -R option to limit this to just
  certain planets. (The times are displayed in the local time zone, and
  are generally accurate to within a half hour or so; Try doing it for
  your birth month and your own chart - All planets should conjunct
  their natal positions at about the time of your birth.) Putting a zero
  in place of the month will cause the entire year to be scanned, which
  prevents one from having to search each month in turn if they are
  looking for something in particular. Note that the -T option includes
  ALL of one's natal house cusps in the transit scans (instead of just
  the Asc and MC). The 11th, 12th, 2nd, and 3rd cusps are included (and
  oppositions to these and the Asc/MC can be used to to determine
  aspects to the other six cusps.)

-T0 <..>: Like -T but include transits of the Moon as well.

  Normally the -T option always ignores the moon and does not include
  the transiting moon in the lists because it moves so fast and would
  cause an enormous amount of info. Still, if you are looking for lunar
  transits, specifying the option as -T0 instead of just -T will include
  the moon.

-Tp <file> <month> <year>: Compute all progressions in month for chart.

  Determining dates of transits of progressed planets to natal planets
  can be done with the -Tp <file> <month> <year> option. This is just
  like the -T option, except that the exact aspects of progressed
  planets (rather than transiting planets) to the planets in 'file' are
  displayed. Again, one can substitute '0' for the month to scan the
  entire year (which might be desirable since progressions occur much
  less often than transits, and there will only be a few, if any, in a
  given month.)

-E <month> <year>: Display ephemeris for given month.

  The '-E <month> <year>' option will generate a quick ephemeris for the
  ten main bodies for the month in question, useful if you just want to
  see what's happening this month in the sky. It generally is used by
  itself and not with any other options. (Displayed daily for midnight,
  default time.) Any dots after a planet location in the list indicate
  the planet was retrograde at the time. The -E <month> <year> ephemeris
  option can also be used to display the ephemeris for the entire year
  instead of just for one month. Like the -T option, putting a '0' for
  the month will give the entire year's ephemeris.

-E0 <..>: Like -E but include Chiron and the asteroids as well.

  The -E option can also display the Asteroids, Chiron, and the Node in
  the ephemeris listing if one invokes it as -E0 instead of just -E.
  Note however that this will make each line more than 80 columns, so
  this is mainly just for printing purposes.

----

Switches to access X window options:

-X: Create a wheel or astro-graph bitmap of chart.

  This is the general switch, which means display a chart in an X window
  instead of on the screen in some form. For example, the command
  'astrolog -i mychart -X' will open a new window and display the chart
  in question in it. (Of course, all the other switches, e.g. -R, -c,
  -1, etc, can be used to change what info is actually displayed.) If
  you use the -L astro-graph switch in addition to this, the appropriate
  astro*carto*graphy map will come up in a window instead of the earlier
  boring list of longitudes. (e.g. astrolog -i me -X -L) The -Z and -g
  switches will produce their own chart types as well, although, of
  course, only one type of chart can be in a window at any given time.

-Xb: Create X bitmap instead of putting graphics in window.

  This switch will cause a standard X11 bitmap file to be produced
  instead of putting the graphics in an actual window. This is useful if
  you want to convert the graphics to different formats, e.g. so they
  can be displayed on PC's, etc. Note that -Xb (or any other -X<letter>
  switch) automatically assumes the -X switch above, so 'astrolog -i
  file -Xb' is sufficient (and you don't also have to include the -X).

-XB: Display X chart on root instead of in a separate window.

  This switch will cause the chart graphics to be displayed directly on
  the root window. This action occurs very quickly since the program
  does not have to write a separate bitmap file and call xsetroot -bitmap
  on it (although one could easily do this if they want to). For example,
  one could put the line 'astrolog -n -XB' in their .xsession file
  and whenever they log in, their background will be set to a chart of
  the current state of the planets!

-Xm: For color monitors, display charts in black and white.

  For color X systems, the -Xm switch will create all windows in
  monochrome B/W mode.

-Xr: Create window or bitmap in reversed colors (B on W).

  Normally the charts comes up white on a black background. To get the
  chart or bitmap displayed in reverse video (black on white), use this
  -Xr switch.

-Xw <hor> [<ver>]: Change the size of the chart window.

  The default window size is 600x600. This can be changed with the -Xw
  switch. -Xw with one argument n will make an n by n window; -Xw with
  two arguments x and y will make an x by y window with the chart
  centered in the middle. Note that this switch will not affect
  astro-graph or aspect grid windows; to change the size of these use
  -Xs below.

-Xs <percentage>: Change the size of characters by n%.

  Note that the size of the planet and sign glyphs don't change when you
  change the size of the window. This can cause problems for very small
  windows where the glyphs overlap the rest of the chart and for very
  large windows where there is lots of excess space. The -Xs switch can
  be used to change the size of all glyphs. The valid values that can be
  passed to it are 100, 200, and 300, where 200 is the default. Note
  that this switch is used to change the size of the astro-graph (and
  aspect grid) windows (because the world map is considered to be one
  giant glyph by the program.)

-Xi: Display chart in slightly modified form.

  Certain people have asked that some of the X charts be modified in
  various minor ways, i.e. in either adding or removing certain
  information. Rather than add a new hard to remember minor option for
  each change, I have added one major new switch which covers all the
  charts. The new -Xi switch will invoke this "induce/inhibit
  information" option, and pressing the 'i' key in a window will
  accomplish the same thing by toggling the mode's status. By default,
  all the charts are as before, but when this bonus option is set, it
  affects each X window chart in a different way, as follows:

 o For the standard -v and relationship -r0 -v wheel charts, it will
   inhibit the display of the aspect grid in the center - useful for
   speed or when doing large time lapse animations when it would get in
   the way.

 o For the -g aspect grid, it will flip the aspects and midpoints across
   the center diagonal, i.e. the midpoints will be below it and the
   aspects above it, instead of the other way around. For the -r0 -g
   relationship aspect grid, the entire grid will be replaced with one
   showing all midpoints between all the objects in the two charts.

 o For the -Z horizon chart and -S space chart, it will, for the major
   planets, increase the size of the "points" showing where each object
   actually is, making a brighter "spot", for easier viewing; combine
   this in the horizon chart with the 'l' key label inhibitor and get a
   very realistic view of the night sky, with planets brighter and all.

 o For the -L astro-graph chart, this will eliminate the display of the
   Ascendant, Descendant, and Nadir lines, leaving just the vertical
   Midheaven lines and zenith points, for a remarkable increase in speed
   and much less clutter when including many objects.

 o For the -XW world map display, this will show the Earth's ley line
   locations by drawing them on top of the map. Familiar with ley lines?
   They are lines of energy crossing the Earth. I was experimenting
   earlier with the master ley line grids on the Earth (in the pattern of
   an overlapped 20 sided Icosahedron and 12 sided Dodecahedron) and I
   figured Astrolog with its world map would be an interesting program to
   explore this with. Actually this is mainly a hack, and belongs more to
   the field of dowsing than to astrology, but I figured I would leave it
   in there for amusement and inspiration. (Hackers note: there is an
   interesting "bug" that can arise with the -XW as well as the -XG (and
   -XP, described below) switches: These displays can be brought up in a
   window without having to specify an actual chart. Now suppose one
   presses 'C', 'W', etc. to bring up a chart - what will be displayed?
   The answer will be whatever default values were already there, and if
   you're curious, it's set to be the program author's own natal chart:
   Nov 19, 1971 11:01am PDT (-8:00 GMT) Seattle, WA 122W20, 47N36.)

 o For the -XP polar globe view, this will show the southern hemisphere
   instead of the northern.

 o For the -XG globe display, it will display the zenith locations of all
   planets (and stars if -U in effect) on the globe, i.e. where on the
   Earth each object could be viewed by looking straight up. This on the
   globe display is almost identical to the astro-graph chart without its
   various lines, except of course that the projection of the world map
   is different. It's also similar to the -Z horizon display, except that
   it's free from the distortion of projecting the celestial sphere upon
   a plane, so it has use to star gazers. However, animation mode here
   will still only affect what part of the Earth is viewable, and won't
   update the chart from which the zenith locations were obtained.

-XT: Inhibit display of chart info at bottom of window.

  Normally, at the bottom of any chart window is printed some header
  information listing the date, time, and location of the chart in
  question. One can inhibit this display by specifying the -XT switch.

-XW: Simply create the bitmap of the world.

  Believe it or not, I painstakingly entered the data for the world map
  used by the program by hand using an Atlas during a long week. If you
  just want to see the map of the world by itself without any
  astro-graph lines on it, use the -XW switch.

-XP: Create the bitmap of the world, but as a polar projection.

  The -XP option will generate a polar view of the Earth as a globe.
  This is like the -XG globe option except that the view is always from
  the top (or bottom). By default, the view is looking down on the north
  pole with 0 deg W/E toward the bottom of the screen. (Animation mode
  will cause the view to spin about the center of the screen.) To see a
  view of the south pole hemisphere, go into the bonus information mode
  described above ('i' key). Again, like with all the other X window
  display modes, one can enter this display with a keystroke: press 'P'
  in any Astrolog window and it will revert to this display.

-XG [<degrees>]: Display the bitmap of the world as a globe.

  Once we have the data for the map of the world, there are
  several neat things we can do with it; for instance, with a little
  trigonometry and clipping, we can bring up a view of a globe, which
  is what the -XG switch does. An optional argument will specify a
  rotation value in degrees to display different parts of the globe.
  (The globe seems to look best for a -Xw window size of around 350.)

-Xn: Start up chart or globe display in animation mode.

  The -Xn [<value>] option can be used to start up an X window in
  animation mode. It a window, one would have to explicitly press 'N' or
  a shift+number key to start the window animation. Without a parameter
  after -Xn, the option will start it up in continuous update to "now"
  mode (which is like pressing 'N' in that any chart will be erased with
  the current chart now.) The switch can accept parameters from 1..9,
  corresponding to the animation rates obtained by pressing shift 1..9
  in the window, i.e. update whatever chart is passed to it seconds,
  minutes, hours, days, months, years, etc. later each time.

-Xo <file>: Write output bitmap to specified file.

  This option is used in conjunction with the -Xb option, to specify the
  name of the file to write the bitmap to.

----

Astrolog window keypress options (version 2.25):

Press 'H' to display this list of key options.

  The most important key, of course. Pressing this will display a help
  list of all the key presses available in the text screen from which
  the window was invoked from.

Press 'p' to toggle pause status on or off.

  Press this to pause all updates to the window. This is mainly used to
  freeze any animation (see below) but also has an effect even on
  'still' windows. Key presses will still be accepted in pause mode but
  their effects won't be apparent until one presses 'p' again to
  continue. This can be used to temporarily freeze a chart in animation
  so that it can be looked at without interruption.

Press 'x' to toggle fg/bg colors in window.

  Pressing this will invert the colors in the window, or in other
  words will do the same thing as the -Xr switch on the command line.

Press 'm' to toggle color/monochrome display in window.

  For color displays, pressing this key will toggle in and out of
  monochrome mode.

Press 'T' to toggle header info on current chart in window.

  Pressing the 'T' key will toggle whether or not the chart parameters
  are printed at the bottom of the window. This corresponds to the -XT
  switch mentioned earlier.

Press 'i' to toggle status of the minor chart modification.

  Pressing this key will toggle whether or not an alternate form of the
  present chart should be displayed. See the -Xi switch described
  earlier for more information on these alternate chart formats.

Press 'l' to toggle labeling of object points in chart.

  Press the 'l' key in a window to inhibit the labeling of all planets
  in the various charts. Instead of drawing the little point and then
  the glyph near it, just the point is displayed. This mode is mainly
  useful for the -Z horizon and -S space charts (and has little use for
  anything else) when in cramped quarters or to get a more realistic
  view of how the sky actually looks.

Press 'v' to display current chart in window on text screen.

  Press this key to dump back to the text screen the list of where all
  the planets currently being displayed in the window are. This display
  is the same as produced with the -v switch, and is useful if one wants
  text to show where everything in the chart is.

Press 'R' to toggle restriction status of minor objects.

  Press the 'R' (restrict) key in an Astrolog X window and the screen
  will be redrawn with the restriction status of these asteroids and
  other minors toggled.

Press 'C' to toggle restriction status of minor house cusps.
Press 'u' to toggle restriction status of uranian planets.
Press 'U' to toggle restriction status of fixed stars.

  Pressing the 'C', 'u', and 'U' keys in the window will toggle the
  restriction status of the four minor house cusps, the uranian planets,
  and the fixed stars, respectively. These keys compliment the 'R' key
  option already in place, and are the counterparts to the -C, -u, -U,
  and -RC, -Ru, -RU options.

Press 's', 'h', 'f', 'F' to toggle status of siderial zodiac,
heliocentric charts, domal charts, and decan charts.

  Press the 's' key in the window to toggle whether or not the siderial
  vs. tropical zodiac is used. Press the 'h' key to toggle to a
  heliocentric based chart or back again to a geocentric one. Press the
  'f' key to toggle the status of whether or not the chart should be
  modified to correspond to the appropriate domal chart (where the house
  positions are represented as zodiac positions and vice versa). Press
  the 'F' key to toggle the status of whether or not the chart should be
  modified to correspond to a decan chart (where each sign is divided in
  thirds representing the two other signs in its element). These keys of
  course correspond the the -s, -h, -f, and -3 options, respectively.

Press 'O' and 'o' to recall/store a previous chart from memory.

  Have you ever animated your natal or some other chart to some far
  distant future or past time, only then to wish you could somehow
  easily get back in time to the original chart? You can, by pressing
  the 'O' key in a window, which will recall to the screen previously
  "saved" chart parameters (which are by default set to whatever you
  started the window with.) Press the 'o' key to change this default
  stored chart to be the chart that is presently in the window.

Press 'B' to dump current window contents to root background.

  Press the 'B' key in an X window to dump whatever is currently being
  displayed to the background root window. This is basically the
  corresponding keypress to the -XB option.

Press 'Q' to resize wheel chart display to a square.

  One can manually resize the Astrolog windows using a window manager
  (except when a world map or aspect grid is displayed, in which case
  any resizing will have no effect). Pressing the 'Q' key will
  automatically resize any (non-world map) window to be a square. This
  is useful, after resizing charts to approximately the size you want,
  to make them precise squares.

Press '<' and '>' to decrease/increase the scale size of the
glyphs and the size of world map.

  This two keys will respectively decrease and increase the size of the
  sign and planet glyphs (as well as resize the astro-graph and aspect
  grid charts) through the three scale factors available. After resizing
  the window, you will probably want to use these keys if the glyphs are
  then too big or small for the new chart.

Press '[' and ']' to decrease/increase tilt in globe display.

  '[', ']' keys: Not only can the globe display be rotated, but the
  poles can be now tilted down at various angles! (This basically makes
  the -XP polar globe view option obsolete; it's still in there only for
  backwards compatibility.) Press the '[' and ']' keys when the globe is
  being displayed to respectively "pull down" and "push back up" the
  angle of the polar axis from which the globe is viewed.  Combining
  this with the globe rotation allows one to move any point of the globe
  to the center of the screen.

Press 'N' to toggle animation status on or off.

  Animation! This key will toggle in and out of a mode where the chart
  is continually updated in the window. Entering the animation mode
  will cause the chart being currently displayed to be replaced by the
  chart for the exact moment at the time you are running the program.
  Every second or two, the chart will be updated to reflect the new
  current state of the planets and houses. For large window sizes, one
  can actually see very minor changes in the chart every few seconds.
  With the text 'T' mode in effect, the chart is basically an advanced
  version of xclock, and makes a good window to be left running on
  your display. If you are in the -XG globe display mode, pressing
  the 'N' key will cause the globe to rotate for an impressive display!

Press '!'-'(' to begin updating current chart by adding times.
!: seconds, @: minutes, #: hours, $: days, : months,
^: years, &: years*10, *: years*100, (: years*1000.

  These nine keys (i.e. shift plus the number keys from 1..9) enter
  into a different form of chart animation. Pressing them will cause the
  current chart being displayed (i.e. it will not revert to the current
  planet positions) to continually have a delta time added to it and be
  recast and shown. Pressing '!' will have one second added to the chart
  for every update (slow action unless you have a very fast system - the
  animation will be even slower than for the 'N' key). Pressing '@' will
  have one minute added to the chart each time, which makes for a nice
  display (note that you will definitely want to be in the text 'T' mode
  for these animations so you can see what times in the future these
  charts are being cast for. Pressing '#" will have one hour added each
  time (note that now the house cusps are starting to move quickly, so
  you may want to switch to a different system of houses (such as the
  Equal to keep the Midheaven from flopping back and forth) and/or use
  -1 to put an object like the sun on the Ascendant.) Pressing '$' will
  have one day added each time (now you will probably want to start
  using -R to remove fast moving objects like the moon), and pressing
  '%' will have one month added for each update of the window. The
  final keys, shift 6..9 cause years, decades, centuries, and millenia
  to be added each time, and tend to only be used to look for long range
  actions (when will Neptune next enter Pisces, etc.) To exit these
  animation modes, press the 'N' key.

Press 'r' to reverse direction of time-lapse or animation.

  Press this to reverse the direction of any animation taking
  place. For the '!'..'(' animation keys above, this will cause
  negative times to be added to the chart, e.g. pressing '#'
  then 'r' on a chart cast for noon will cause the next chart to
  be displayed for 11am, then 10am, etc. For the Globe animation,
  this will cause the rotation to reverse direction.

Press '1'-'9' to set rate of animation to 'n' degrees, etc.

  The nine number keys are used to set the relative "rate" of
  animation to "n" whatevers. For example, normally the "@" key means
  add one minute to the chart for each update, but press "5" and now
  we are adding 5 minutes each time. For the Globe animation,
  by default the Earth rotates one degree each time; however, the
  number keys can speed this up to nine degrees for each update.

Press 'V','L','A','Z','S','W','G','P' to switch to normal (-v),
astrograph (-L), grid (-g), local (-Z), space (-S),
world (-XW), globe (-XG), and polar (-XP) modes.

  There are basically eight main modes in which a window can be in:
  There are the five main charts (wheel, astro-graph, aspect grids,
  local sky, and space view) as well as the three world displays (the
  simple map by itself, the globe view, and the polar projection). These
  eight keys can be used to switch between these eight modes in the
  middle of program execution. For example, you can bring up your own
  chart in a window, then press 'L' to see the astro-graph chart for the
  same birth data. Then you can press 'W' to just see the world map by
  itself, and 'G' to see the globe view, after which you can press 'V'
  to return to your original wheel chart.

Press 'q' to terminate the window and program.

  Pressing this key will terminate the window (and the Astrolog
  program itself.)

----

Left   mouse button: Draw lines on chart in window.
Middle mouse button: Print coordinates of pointer on world map.
Right  mouse button: Terminate the window and program.

  Mouse buttons: Pressing the mouse buttons in the X windows will do
  various functions. The left mouse button acts as a pen that allows one
  to actually draw on the chart: press it and drag the pointer to draw a
  line on the window - good for aiding in analysis or in presentations.
  (Any scribbles one makes will disappear the next time the chart window
  is updated, therefore drawing will have little effect when in
  animation mode.) The middle mouse button will only work when the world
  map is shown, i.e. in the -L astrograph or -XW world map displays:
  press it and get the approximate longitude and latitude of the place
  on the map where the pointer is. For the three scale sizes of 100,
  200, and 300 percent, the accuracy is to the nearest degree, 30', and
  20', respectively. So, if you want to cast a chart for southern
  Madagascar, Africa, but don't know the coordinates, click the middle
  button on the map for a good approximation! Finally, the right button
  acts just like the 'q' key, and will terminate the window.


******************************
THE DISPLAY AND OTHER FEATURES
******************************

The main part of the program is executed simply by entering "astrolog"
(assuming that's the name of the executable), and the program will ask
you for all the birth info and will give the planet/house positions.
(e.g. for here in Seattle right now for the seven prompts I would
enter [for June 11th, 1992 AD at 10:22pm, with daylight time in effect
- if daylight time were *not* in effect, I would have entered 22.22
for the fourth value instead]: 6; 11; 1992; 21.22; 122.20; 47.36) The
program then calculates and displays the positions of all planets,
Chiron, the four main asteroids, as well as stuff like the Part of
Fortune and the Vertex. (The Uranian bodies and fixed stars can also
be listed if one includes the appropriate command switches described
earlier.)

Information in addition to the above planet positions are shown in the
main display when the chart is cast: (1) Whether or not each planet is
in it's ruling sign, or fall, as well as displaying the same
information for ruling or debilitating houses. (2) The sum of the
signs in each element and mode and their totals is displayed in a grid
form. Also, planets in their exalted and debilitated signs are noted.
In addition to the (R) indicating a planet in it's ruling sign, and an
(F) for a planet in it's fall, we have (e) if a planet is in its
exalting sign, and a (d) for a planet in its debilitating sign (which
is always opposite the exaltation, as how the fall is opposite the
ruler).

This standard chart listing of the planetary positions includes an
additional field for the "velocity" of each planet. This velocity
value approximates how fast the planet is moving through the zodiac
with respect to the Earth (or whatever the central body is set to) in
degrees per day. This value of course, goes negative when a planet
goes retrograde. This is useful not only to get a feel for how fast
each planet moves through the zodiac, but to determine when a planet
is about to go retrograde or direct - the value approaches zero when
the planet changes direction.

Also in the main display, the total number of planets in each of the
hemispheres of the wheel, as well the number of objects in
positive/masculine and negative/feminine quality signs, are counted.
To the right of the element table, we have a column of six numbers
labeled as follows: "+" is the number of "positive" objects (i.e. in
Fire or Air signs); "-" is the number of "negative" objects (i.e. in
Water or Earth signs); "M" is the number of objects above the horizon
(i.e. in the hemisphere of the Midheaven); "N" is the number of
objects below the horizon (in the hemisphere of the Nadir); "A" is the
number of objects in the Eastern half of the sky (in the hemisphere of
the Ascendant); and "D" is the number of objects in the Western half
of the sky (in the hemisphere of the Descendant).

--

Astrolog includes the ability to search an input file for various
default parameters to use in the program. This allows one to easily
change major defaults without having to recompile the program, which
is useful if, say, one receives a compiled executable from a friend
who had a different configuration. The program looks for the file
"astrolog.dat" in the current directory, and if not there, looks for
it in the default directory. Parameters in this file will override any
defaults compiled into the program, although the highest priority is
still given to the command line options. Note one doesn't *have* to
have this file in order to run the program - if not found Astrolog
will still run as before. Presently, the parameters one can change in
this file are: default time zone (as indicated with -z option),
default longitude and latitude (as in -l option), number of aspects
(-A option), default house system to use (values as in -c option).
Then come default restriction values (as with -R option) for the first
20 objects (0 = active, 1 = restricted). Next are the orbs (as with
-Ao option) for the 18 aspects. Finally, comes a long list of the
influence values used by the -I option, i.e. the power values of each
of the first 20 planet objects, of the 12 houses, and of the 18
aspects. The only major thing that one *can't* change in the file is
the default directory path in which the program looks in for input
files if not in the current directory, since Astrolog needs the
default directory in order to be able to locate the file in the first
place! The "astrolog.dat" file included with this version of the
program has some "comment lines" describing what is contained in each
line. One can chance or delete comments as long as they make sure that
an equals sign ('=') immediately proceeds any value or list of values,
since the program uses this character to determine where comments end.

--

I often use Astrolog to look at and compare files containing charts of
various people. I have many chart files, so I keep them in a separate
directory. Since it is always a pain to have to cd into this special
directory all the time, there is a DEFAULT_DIR string to be set at
compile time. Whenever the program reads in a chart file with the -i
option, it will first look in the current directory for it. If it's
not found there, Astrolog will then look for a file of the same name
in the special default directory.

A couple of people have e-mailed me saying that their computer (for
example, Mac's) won't accept command switches on the command line
(like they boot Astrolog from a menu for instance.) Therefore, they
aren't able to access many features in the normal way. If this is the
case with your system (or if you just don't like command line
options), then comment out the '#define SWITCHES' line at the
beginning of the astrolog.h file. If you do this, then the program
will ignore any switches and prompt you to enter them manually at the
very beginning of program execution.

A couple of other compile time option variables are in the include
file astrolog.h: For those people who don't like Placidus, a default
house system can be set by changing the value of DEFAULT_SYSTEM to the
value from 0..9 indicating what system to use if the user doesn't
explicitly specify it with -c. Another thing: It should be mentioned
that although the accuracy of Sun..Pluto, Chiron, and the Uranians are
to the nearest minute (for years 1900-2000), the four asteroids are
relatively inaccurate and can even be a couple of degrees off in the
worst case. Also, some people just don't like or care about those
minor bodies and think that they clutter up the various charts. If you
don't want the values of the asteroids, Chiron, Part of Fortune, and
the Vertex to appear in the program by default, there is a #define in
astrolog.h called ASTEROIDS that can be commented out so that it will
be as if -R is always included when the program is run. (Simply do -R
to get them *back* if you compile it this way.) Or better yet, change
the default restrictions to your preference by editing the
astrolog.dat default parameter file described above.

Note for PC users: I have tried to make this program as much
executable on personal computers and other non-unix systems as
possible. Although this version should be easier to compile than
previous ones were, still there are probably some things I've
forgotten or left out. Another warning for PC users: You will probably
want to change the value of DIVISIONS in astrolog.h from its current
value of 24 to a lower value like 6 or so.  Leaving it as is invoked
complaints of extreme slowness and occasional multiple hits in the -d
aspect search routine, where the same aspect would get listed more
than once.


********************************
DESCRIPTION OF X WINDOW FEATURES
********************************

One of the most impressive features of the program are the X windows
features, which are generally accessed in the program via the -X
switch and derivatives of it on the command line. There are five
different types of chart displays: A standard graphic display of a
wheel chart in a window (with glyphs, aspects in the center, etc),
graphic displays of the Astro-graph charts (which look almost
identical to the astro*carto*graphy maps from Jim Lewis) complete with
all the labeled lines drawn on a map of the world (like the -L
option), aspect/midpoint grids showing the aspects and orbs in effect
between every body in a chart (like -g option), a local sky chart
showing where each planet is located on a map of the local horizon
area (as in -Z), and a space chart showing an aerial view of the solar
system (as in -S). The X wheel and aspect grid charts can displayed
in a different form to accomodate relationship comparison charts.
There are also other commands that can be given to the window once it
is up and running, which can do other things, such as continually
update the window every few seconds to the current status (i.e. an
extended version of the -n option) as well as other forms of
animation. Note that the program is still text based, and one can
easily turn off all the X features by commenting out the #define X11
in astrolog.h if they don't have X windows.

Probably the only thing more impressive than the X window features are
the X window features displayed on color monitors. (The charts
displayed in color are *much* more eye catching than the B/W ones,
IMHO.) Here is how the colors have been assigned for the various
charts: Four colors have been allocated for the four elements - Fire =
Red, Earth = Brown, Air = Green, Water = Blue. The various sign glyphs
(and the corresponding house labels) are in the color of their
element. Planets are in the color of the sign of their main ruler.
Chiron and the four asteroids are Gold, while the north node, and
other non-physical objects like the fortune and vertex are Violet.
Representations of the Ascendant/ Descendant/ Midheaven/ Nadir (in the
astro-graph map lines and elsewhere) are in the element color of the
corresponding sign/house that the angular lines refer to, i.e.
Ascendant = Red, Midheaven = Brown, Descendant = Green, Nadir = Blue.
A few extra things have been added for color wheel charts only: dark
gray lines marking off each house (in addition to the main lines on
the horizon and meridian), and each degree instead of every 5th degree
being marked in dark gray on the outer circle (every 5th degree being
white). Aspects lines are colored too, as follows: Conjunctions =
Yellow, Sextiles = Light Blue, Squares = Red, Trines = Green,
Oppositions = Dark Blue. For the minor aspects we have:
Inconjuncts/Semisextiles = Brown, Semisquares/ Sesquiquadratures =
Orange, (Bi/Semi)Quintiles = Violet, (Bi/Tri)Septiles = Gold,
(Bi/Quatro)Noviles = Pink.

The X wheel charts have their graphic information organized as
follows: There's an outer circle showing the signs and sign glyphs,
inside of which is a smaller circle divided up into 5 degree
increments to make determining exact degrees easier. Inside of this is
a circle divided up into the 12 houses labeled with numbers. The
entire chart is divided by two dashed lines through the Ascendant/
Descendant (which is always horizontal of course) and the
Midheaven/Nadir. Inside the house circle are the planet glyphs in
their appropriate positions. Small pointer lines run from each glyph
to just before single dots. These dots indicate the precise locations
in the zodiac of each object. The pointer lines (which are dashed if
the object is retrograde and solid otherwise) are necessary so as not
to have to draw planet glyphs on top of one another when planets are
conjunct. Inside the ring of the single dots, are the aspect lines
connecting these positions. Since the default number of aspects to use
is just the 5 majors, one can determine which aspect is in place just
by looking at the aspect line. The accuracy of the aspect is
determined by the dashedness of the line: A solid line means the orb
is < 2 degrees; a dashed line means the orb is < 4 degrees; a really
dashed line mean the orb is < 6 degrees, etc.

The X astro-graph charts are organized as follows: A map of the world
is shown. The edges of the map are labeled with ruler lines that are 5
degrees apart (with longer ruler lines for more important longitudes
and latitudes, like those that are multiples of 10, 30, etc.) The
equator is labeled with a dashed line. The polar regions of the world
aren't shown; the map shown ranges from 60 degrees S latitude to 75
degrees N latitude. Note that each pixel on the screen represents
exactly one half a degree on the world. (For -Xs 100 the ratio is one
pixel to one degree, and for -Xs 300 the ratio is one pixel to 1/3
degree.) On this map are drawn the lines indicating where on the world
the various planets are angular at the time in question. (Note: you
might want to -R restrict some objects because otherwise the map tends
to get pretty cluttered with lines.) As expected, Midheaven and Nadir
lines are vertical, and the Ascendant and Descendant lines are curved.
Little square boxes on the Midheaven lines indicate the exact zenith
latitude location. Each line is labeled at the top or the bottom of
the screen, showing what planet is in question and (sometimes) what
angle is in question. All Ascendant and Midheaven lines are labeled
at the bottom of the screen, and all Descendant and Nadir lines are
labeled at the top. Each line goes a bit beyond to the top or bottom
of the world map, and then another pointer segment (which is again
dashed of the object in question is retrograde) goes and points to the
planet glyph. There is a capital "A" or "M" under each of the glyphs
at the bottom of the screen, explicitly indicating whether the line is
an Ascendant or Midheaven line. At the top of the screen, however,
there are only the glyphs, but one can still determine whether these
lines are Descendant or Nadir lines based on whether they are curved
or not. Note that not all the Descendant lines are labeled; this is
because some of the Ascendant/Descendant lines actually connect near
the top of the screen and don't actually cross it.

Aspect grid windows with the appropriate aspect glyphs can be
displayed by combining the -g option with the -X option (astrolog -g
-X). Both the split aspect/midpoint grids labeled down the diagonal,
as well as the relationship aspect grids between two charts (astrolog
-r <file1> <file2> -g -X) are supported. The aspects glyphs, objects,
and the signs in the grids are in their colors as defined earlier.
Like the astro-graph windows, these charts can't be resized in the
normal way unless one uses the '>' and '<' keys. For anything less
than the largest scale size (achieved with the switch -Xs 300, or by
pressing '>' within a window) all that will be displayed in each
aspect grid cell is the glyphs of the aspect in effect, the planet
being aspected, or the sign of the midpoint. However, once the largest
scale size is reached, there is room in each cell to display the
aspect orb to the nearest minute off of exact (with a plus or minus
sign indicating whether the actual angle is slightly greater than or
less than exact); the degree and minute in addition to the sign for
midpoints; and the degree and sign location for each planet that's in
the grid. Remember, the ASCII aspect grids in the text options are
rather limited, only displaying orbs to the nearest 0.1 degree,
midpoints to the nearest degree, as well as the confusing '.' vs. ','
for angles slightly greater or less than exact (not to mention leaving
the vertex out for the relationship grids between two charts). Well no
longer: with X11, we can see *real* aspect grids with Astrolog!

The -Z local horizon feature can be displayed in an X window as well
(e.g. astrolog -Z -X), in which all the planets will be displayed in a
window depicting the sky. The small dot above or below each glyph
indicates exactly where each planet is. (Some of the glyphs may be
overlapping, although the program tries to cut down on this.) There
is a horizontal line dividing the window representing the local
horizon; planets above this line are visible, while planets below it
are set. There are three vertical lines dividing the window as well:
The middle line represents the due south direction, the one to the
left is due east, the one to the right is due west, and the edges of
the window are due north. Like the standard chart display, this window
may be resized to any proportion. One can press the 'Z' key in any
window to enter this display type in that window at any time.

The -S switch can be combined with -X to give an X window chart of the
solar system. This will be displayed as an aerial view of the entire
solar system, with 0 degrees Aries to the left of the screen, and 0
degrees Cancer to the bottom. Note that this chart includes all
possible planets, including the Earth (whose glyph is a cross inside a
circle). Whatever object is chosen to be the central body is at the
center of the screen, with all the others around it. This is a fun
chart to animate - watch the planets go around the Sun, and *see* how
they turn retrograde with respect to the Earth. In addition to the
bodies themselves, twelve spokes are drawn from the center body to the
edge of the screen, which delineate the zodiac with respect to it.
Note that the scale of the solar system is large; attempting to fit
all the planets out to Pluto on the screen at once will cause all the
inner planets to be crammed together near the middle of the screen. To
deal with this, the scale size as indicated with the -Xs switch and
the '<' and '>' keys will affect how much of the solar system is
viewed at once (in addition to the glyph sizes). For a scale size of
300, the viewport will have a radius of 6 AU (about out to the orbit
of Jupiter; useful for viewing the inner planets). For a scale size of
200 (default), it will have a radius of 30 AU (enough to include
Neptune, and Pluto most of the time). Finally, a scale size of 100
will result in a radius of 90 AU, enough to easily include the entire
solar system, as well as the orbits of the alleged Uranian bodies
beyond Pluto.

True relationship wheel charts can be displayed in a window, i.e.
where the planets of both charts are displayed in separate rings of
the same wheel. Use the -r0 option to display this comparison type.
For example, for the command "astrolog -r0 person1 person2 -X", the
following is displayed: The signs and houses as in person1's chart are
drawn in the outermost part of the wheel. Inside this is a ring of
person2's planets as displayed in person1's houses, and inside of this
are person1's own planets. Finally at the very middle is an aspect
grid, which shows those aspects that are occurring between the objects
in the two charts. Basically this is just the standard wheel chart for
person1, except that person2's planets are in an outer ring of objects
and the aspect grid shows the aspects of the relationship. Putting
such a chart in animation mode only affects person2's planets, so this
is a great way to analyze transits: Doing "astrolog -t yourchartfile
-X" will show all your current transits, and allow you to easily
animate the transiting planets through your natal signs and houses.

For color X terminals, the -XG globe display and -XW world map display
are done with the continents in different colors! This makes them look
much better than monochrome maps. Each of the seven continents is in a
different color of the rainbow, and the colors are chosen to
correspond to the appropriate chakra (etheric energy vortex along the
human spine) that goes with each land mass.  They are: Africa - red -
Root chakra, Australia - orange - Navel chakra, South America - yellow
- Solar plexus chakra, North America - green - Heart chakra, Europe -
blue - Throat chakra, Asia - indigo - Third Eye chakra, Antarctica -
violet - Crown chakra. Major lakes are, of course, colored navy blue.

--

A couple of conveniences for the X window features exist. Note that
the -Xo <bitmapfilename> option is only used in conjunction with the
-Xb write output to bitmap switch. Therefore, -Xo automatically
assumes -Xb is set. (Invoking -Xb itself without -Xo will have the
program prompt the user for the bitmap filename.) In other words,
astrolog -Xb -Xo 'file' is the same as just astrolog -Xo 'file'. (This
may change if I add other file types, but for now none are planned.)
Also, I should mention that Astrolog includes its own appropriate
bitmap (a rainbow over an opened Third Eye) if one iconifies the
window, instead of reverting to the braindead UnknownIcon :)

-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-
|    Walter D. "Cruiser1" Pullen    |    cruiser1@milton.u.washington.edu.    |
-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-|-
